#
# spec file for package aws-c-auth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define library_version 1.0.0
%define library_pkg 1_0_0
%define library_soversion 1
Name:           aws-c-auth
Version:        0.8.0
Release:        1.2
Summary:        AWS C99 library implementation of AWS client-side authentication
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/awslabs/aws-c-auth
Source0:        https://github.com/awslabs/%{name}/archive/v%{version}.tar.gz
Patch0:         aca_fix-cmake-modules-path.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  cmake(aws-c-common)
BuildRequires:  cmake(aws-c-compression)
BuildRequires:  cmake(aws-c-cal)
BuildRequires:  cmake(aws-c-http)
BuildRequires:  cmake(aws-c-io)
BuildRequires:  cmake(aws-c-sdkutils)
BuildRequires:  cmake(s2n)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  ninja
BuildRequires:  pkgconfig

%description
C99 library implementation of AWS client-side authentication: standard
credentials providers and signing.

From a cryptographic perspective, only functions with the suffix "_constant_time"
should be considered constant time.

%package -n lib%{name}%{library_pkg}
Summary:        Shared library files for aws-c-auth library
Group:          Development/Libraries/C and C++
Provides:       lib%{name}%{library_soversion} = %{version}
Obsoletes:      lib%{name}%{library_soversion} <= %{version}

%description -n lib%{name}%{library_pkg}
AWS C99 library implementation of AWS client-side authentication:
standard credentials providers and signing.

This package contains the dynamically linked library.

%package devel
Summary:        Development files for aws-c-auth library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{library_pkg} = %{version}

%description devel
AWS C99 library implementation of AWS client-side authentication:
standard credentials providers and signing.

This package contains the development files.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake \
    -DCMAKE_BUILD_TYPE=Release
%make_jobs

# Testsuite currently hangs
# see: https://github.com/awslabs/aws-c-auth/issues/147
#%%check
#export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build
#%%ctest

%install
%cmake_install
ln -s lib%{name}.so.%{library_version} %{buildroot}%{_libdir}/lib%{name}.so.%{library_soversion}

%post -n lib%{name}%{library_pkg} -p /sbin/ldconfig
%postun -n lib%{name}%{library_pkg} -p /sbin/ldconfig

%files -n lib%{name}%{library_pkg}
%doc README.md
%license LICENSE
%{_libdir}/*.so.%{library_soversion}
%{_libdir}/*.so.%{library_version}

%files devel
%{_libdir}/cmake/%{name}/
%{_libdir}/*.so
%{_includedir}/*

%changelog
* Thu Oct 24 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.8.0
  * Update CMake to 3.9 by @waahm7 in (#255)
* Tue Sep 17 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.31
  * Add more partitions for sts cred provider
    by @DmitriyMusatkin in (#253)
- from version 0.7.30
  * Fix Multiple Shutdown Callback for Profile with
    STS Code Path by @waahm7 in (#251)
- from version 0.7.29
  * When sourcing credentials from an external process,
    ignore stderr by @graebm in (#250)
- from version 0.7.28
  * Service specific presign by @TingDaoK in (#249)
* Thu Sep  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.27
  * Add content-sha256 header for presign when the signed_body_value
    is set to UNSIGNED-PAYLOAD by @TingDaoK in (#248)
* Mon Aug 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.26
  * Update CacheCredentialsProvider Refresh Time to
    5 Minutes before Expiry by @waahm7 in (#247)
* Wed Aug  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.25
  * Add ProcessProvider to ProfileProvider by @waahm7 in (#245)
* Fri Aug  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.24
  * Fix Empty Env varibales for STSWebIdentity by @waahm7 in (#246)
* Wed Jul 31 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.23
  * Ecforce ECS Credentials Provider IP Rules by @waahm7 in (#238)
  * clang-format 18 by @graebm in (#242)
  * Update MacOS to arm64 by @waahm7 in (#243)
  * Support "external_id" in config file,
    for STS AssumeRole by @graebm in (#244)
* Thu Jun 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.22
  * trivial: add_net_test_case for credentials_provider_ecs_basic_success_uri_env
    test by @waahm7 in (#240)
* Mon May 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.21
  * Fix STSCredentialsProvider Signing Region by @waahm7 in (#239)
- from version 0.7.20
  * Fix STS Credentials Provider to use regional
    endpoint if possible by @waahm7 in (#237)
* Wed May  8 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.19
  * Refactor ECSCredentialsProvider Part 1 by @waahm7 in (#236)
  * Refactor ECSCredentialsProvider Part 2 by @waahm7 in (#235)
- from version 0.7.18
  * Update ECS Credentials Provider to add support for
    AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE by @waahm7 in (#233)
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.17
  * Additional logging for default credentials chain by @jamesbornholt in (#231)
  * Remove unused test files by @jmklix in (#232)
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Feb 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.16
  * Fix a bunch of places we forget to aws_raise_error() by @graebm in (#229)
- from version 0.7.15
  * Make Partial Creds a Transient Error by @waahm7 in (#226)
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- fix packaging shlib naming
* Fri Jan 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.14
  * Make Partial Creds a Transient Error by @waahm7 in (#226)
- from version 0.7.13
  * Handle empty path in AWS_CONTAINER_CREDENTIALS_FULL_URI
    by @jamesbornholt in (#225)
- from version 0.7.12
  * Remove old test files by @graebm in (#223)
  * Add assumeRole chain support by @waahm7 in (#224)
- from version 0.7.11
  * Add an option to disable environment credentials provider
    in the default chain by @waahm7 in (#222)
* Wed Jan  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.10
  * Change `port` from uint16_t to uint32_t to support VSOCK by @graebm in (#220)
- from version 0.7.9
  * Fix error when tests run in parallel by @graebm in (#221)
* Thu Nov 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.8
  * Performance optimization updates by @TingDaoK in (#219)
* Tue Nov 21 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.7
  * Add an Option to Disable v2 to v1 Fallback by @waahm7 in (#218)
- from version 0.7.6
  * Fix the imds client endless retry by @TingDaoK in (#217)
- from version 0.7.5
  * aws_signable refcounts request by @graebm in (#216)
- from version 0.7.4
  * Increase ancient bot by @jmklix in (#199)
  * Fix permissions for stale issue bot by @jmklix in (#212)
  * Minor CMakelists.txt cleanup by @graebm in (#213)
  * Added workflow for handling answerable discussions
    by @yasminetalby in (#214)
  * StsWebIdentity allow parameters by @waahm7 in (#215)
* Tue Aug 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.3
  * Remove Outdated Comment by @waahm7 in (#210)
  * Fix ProcessCredentialsProvider Callback to
    trigger once by @waahm7 in (#211)
* Tue Jul 25 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.2
  * Allow Overriding of Profile in Default Chain by @waahm7 in (#209)
- from version 0.7.1
  * Treat empty environment variable as unset by @TingDaoK in (#206)
  * Adapt to XML API changes by @graebm in (#207)
* Wed Jul  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.0
  * Fix session token in ProcessCredentialsProvider by @waahm7 in (#205)
* Mon Jul  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.30
  * Add process credentials provider in default chain by @waahm7 in (#204)
* Fri Jun 23 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.29
  * Don't use the default cursor to override if
    no override needed by @TingDaoK in (#200)
  * Fix the function that saying accepting null
    but actually not by @TingDaoK in (#201)
  * Send Host header in IMDS requests
    by @jamesbornholt in (#203)
* Tue May 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.28
  * Fix warnings in public headers by @waahm7 in (#198)
* Tue May  9 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.27
  * Fix aws_parse_credentials_from_json_document by @waahm7 in (#192)
  * Fix the doc, decrement for release by @TingDaoK in (#194)
  * Add github templates and bots by @jmklix in (#196)
  * Update builder version to fix aws-lc build
    on manylinux-1 by @TingDaoK in (#197)
  * Implement SSOCredentialsProvider by @waahm7 in (#189)
* Wed Mar 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.26
  * Add Option to Use Cached Profile Collection by @waahm7 in (#187)
* Fri Mar  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.25
  * Event Signing Support via Sigv4 by @waahm7 in (#186)
* Fri Feb  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.24
  * Fix trailer signing by @waahm7 in (#184)
- from version 0.6.23
  * Adds default monitoring options for IMDS client by @waahm7 in (#183)
- from version 0.6.22
  * Add codecov action by @TingDaoK in (#180)
  * Fix macro usage by @DmitriyMusatkin in (#181)
* Tue Nov 22 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.21
  * Add delegate failure error code by @waahm7 in (#179)
* Fri Nov 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.20
  * Update CI by @waahm7 in (#177)
- from version 0.6.19
  * Fix C++ One Definition Rules (ODR) Violations by @graebm in (#178)
* Wed Nov  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.18
  * Cognito tests require networking by @graebm in (#176)
* Wed Oct  5 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.17
  * Adds basic cognito credentials provider implementation
* Fri Sep  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.6.16
  * Use the default load target function by @TingDaoK in (#172)
- from version 0.6.15
  * Adds support for Anonymous Credentials by @waahm7 in (#171)
- from version 0.6.14
  * Expiration override by @bretambrose in (#166)
  * STS web ID default by @bretambrose in (#167)
  * Never sign "Expect" header by @graebm in (#170)
- Add rpmlint override for bogus shlib-policy-name-error
  * aws-c-auth-rpmlintrc
* Thu Apr 28 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.6.13
